#
# spec file for package light-locker
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           light-locker
Version:        1.9.0
Release:        1.23
Summary:        A simple locker using LightDM
License:        GPL-2.0-or-later
URL:            https://github.com/the-cavalry/light-locker
Source:         https://github.com/the-cavalry/light-locker/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  intltool
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dbus-glib-1) >= 0.30
BuildRequires:  pkgconfig(gobject-2.0) >= 2.25.6
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libsystemd) >= 209
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xscrnsaver)
BuildRequires:  pkgconfig(xxf86vm)
Requires:       lightdm >= 1.7.10
Recommends:     %{name}-lang
%glib2_gsettings_schema_requires

%description
light-locker is a simple locker that aims to have simple, sane, secure
defaults and be well integrated with the desktop while not carrying any
desktop-specific dependencies.
It relies on LightDM for locking and unlocking your session via systemd.

%lang_package

%prep
%setup -q

[ $(readlink README) != README.md ]
rm README && ln -s README.md README

%build
%meson \
  -Ddpms-ext=true      \
  -Dmit-ext=true       \
  -Dxf86gamma-ext=true
%meson_build

%install
%meson_install
%find_lang %{name}

%files
%license COPYING
%doc AUTHORS NEWS README.md
%{_bindir}/%{name}
%{_bindir}/%{name}-command
%{_datadir}/glib-2.0/schemas/*%{name}.gschema.xml
%{_sysconfdir}/xdg/autostart/%{name}.desktop
%{_mandir}/man?/%{name}*.?%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Tue Oct 29 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.9.0:
  * Add Meson build system.
  * Fallback to XDG_SESSION_ID if sd_pid_get_session fails.
  * Remove GTK 2 support.
  * Remove ConsoleKit support.
  * Update translations.
* Thu Nov 15 2018 sor.alexei@meowr.ru
- Update to version 1.8.0:
  * Build against newer systemd.
  * Add information for debugging.
  * Proper exit codes for light-locker-command.
  * Update translations.
- Remove light-locker-systemd-209.patch: fixed upstream.
* Mon Dec 12 2016 dimstar@opensuse.org
- Add light-locker-systemd-209.patch to update build system for
  systemd >= 209:
  + libsystemd-login has been merged into libsystemd. With version
    230, the compatibility libraries are dropped.
- Change pkgconfig(libsystemd-login) BuildRequires to
  pkgconfig(libsystem).
* Sat Oct 31 2015 sor.alexei@meowr.ru
- Update to 1.7.0:
  * Use lid status for locking and VT switching.
  * Use systemd suspend delay to lock on suspend.
  * Set systemd IdleHint.
  * More small changes.
  * Update translations.
* Sat Mar 21 2015 sor.alexei@meowr.ru
- Actually enable X11 Screen Saver extension.
* Wed Mar 11 2015 sor.alexei@meowr.ru
- Update to 1.6.0 (changes since 1.4.0):
  * Add DBus interface to communicate with the running light-locker.
  * Add GSettings backend to store light-locker configuration.
  * DBus compatibility with KDE and GNOME.
  * Optionally execute command with lock inhibition taken.
  * Man page update.
  * Translations update.
  * New translations.
- Enable DPMS and X11 Screen Saver extensions.
* Fri Apr 18 2014 sor.alexei@meowr.ru
- Initial package.
